Crate solana_runtime

Crate solana_runtime 

Modules

account_saver
accounts_background_service
Service to clean up dead slots in accounts_db
bank
The bank module tracks client accounts and the progress of on-chain programs.
bank_client
bank_forks
The bank_forks module implements BankForks a DAG of checkpointed Banks
bank_forks_controller
bank_utils
block_component_processor
commitment
dependency_tracker
Utility to track dependent work.
epoch_stakes
genesis_utils
inflation_rewards
Information about stake and voter rewards based on stake state.
installed_scheduler_pool
Transaction processing glue code, mainly consisting of Object-safe traits
leader_schedule_utils
loader_utils
non_circulating_supply
prioritization_fee
prioritization_fee_cache
rent_collector
runtime_config
serde_snapshot
slot_params
snapshot_bank_utils
snapshot_controller
snapshot_minimizer
Used to create minimal snapshots - separated here to keep accounts_db simpler
snapshot_package
snapshot_utils
stake_account
stake_history
This module implements clone-on-write semantics for the SDK’s StakeHistory to reduce unnecessary cloning of the underlying vector.
stake_utils
stake_weighted_timestamp
stakes
Stakes serve as a cache of stake and vote accounts to derive node stakes
static_ids
status_cache
test_utils
transaction_batch
validated_block_finalization
Validated block finalization certificates.
validated_reward_certificate
vote_sender_types