[−][src]Module solana_runtime::append_vec
Modules
| test_utils |
Structs
| AccountBalance | |
| AppendVec | |
| StorageMeta | StorageMeta contains enough context to recover the index from storage itself |
| StoredAccount | References to Memory Mapped memory The Account is stored separately from its data, so getting the actual account requires a clone |