Struct solana_runtime::append_vec::AccountMeta [−][src]
pub struct AccountMeta {
pub lamports: u64,
pub owner: Pubkey,
pub executable: bool,
pub rent_epoch: Epoch,
}Expand description
This struct will be backed by mmaped and snapshotted data files. So the data layout must be stable and consistent across the entire cluster!
Fields
lamports: u64Expand description
lamports in the account
owner: PubkeyExpand description
the program that owns this account. If executable, the program that loads this account.
executable: boolExpand description
this account’s data contains a loaded program (and is now read-only)
rent_epoch: EpochExpand description
the epoch at which this account will next owe rent