BankFieldsToSerialize

Struct BankFieldsToSerialize 

pub struct BankFieldsToSerialize {
Show 27 fields pub blockhash_queue: BlockhashQueue, pub hash: Hash, pub parent_hash: Hash, pub parent_slot: Slot, pub hard_forks: HardForks, pub transaction_count: u64, pub tick_height: u64, pub signature_count: u64, pub capitalization: u64, pub max_tick_height: u64, pub hashes_per_tick: Option<u64>, pub ticks_per_slot: u64, pub ns_per_slot: u128, pub genesis_creation_time: UnixTimestamp, pub slots_per_year: f64, pub slot: Slot, pub block_height: u64, pub leader_id: Pubkey, pub fee_rate_governor: FeeRateGovernor, pub epoch_schedule: EpochSchedule, pub inflation: Inflation, pub stakes: Stakes<StakeAccount<Delegation>>, pub is_delta: bool, pub accounts_data_len: u64, pub versioned_epoch_stakes: HashMap<u64, VersionedEpochStakes>, pub accounts_lt_hash: AccountsLtHash, pub block_id: Hash,
}
Bank’s common fields shared by all supported snapshot versions for serialization. This was separated from BankFieldsToDeserialize to avoid cloning by using refs. So, sync fields with BankFieldsToDeserialize! all members are made public to keep Bank private and to make versioned serializer workable on this. Note that some fields are missing from the serializer struct. This is because of fields added later. Since it is difficult to insert fields to serialize/deserialize against existing code already deployed, new fields can be optionally serialized and optionally deserialized. At some point, the serialization and deserialization will use a new mechanism or otherwise be in sync more clearly.

Fields

blockhash_queue: BlockhashQueuehash: Hashparent_hash: Hashparent_slot: Slothard_forks: HardForkstransaction_count: u64tick_height: u64signature_count: u64capitalization: u64max_tick_height: u64hashes_per_tick: Option<u64>ticks_per_slot: u64ns_per_slot: u128genesis_creation_time: UnixTimestampslots_per_year: f64slot: Slotblock_height: u64leader_id: Pubkeyfee_rate_governor: FeeRateGovernorepoch_schedule: EpochScheduleinflation: Inflationstakes: Stakes<StakeAccount<Delegation>>is_delta: boolaccounts_data_len: u64versioned_epoch_stakes: HashMap<u64, VersionedEpochStakes>accounts_lt_hash: AccountsLtHashblock_id: Hash

Implementations

Source

impl BankFieldsToSerialize

pub fn default_for_tests() -> Self

Create a new BankFieldsToSerialize where basically every field is defaulted. Only use for tests; many of the fields are invalid!