pub struct BlockComponentProcessor { /* private fields */ }Implementations
Sourceimpl BlockComponentProcessor
impl BlockComponentProcessor
pub fn on_final( &self, migration_status: &MigrationStatus, slot: Slot, ) -> Result<(), BlockComponentProcessorError>
Sourcepub fn on_entry_batch(
&mut self,
migration_status: &MigrationStatus,
slot: Slot,
) -> Result<(), BlockComponentProcessorError>
pub fn on_entry_batch( &mut self, migration_status: &MigrationStatus, slot: Slot, ) -> Result<(), BlockComponentProcessorError>
Process an entry batch.
Validates that a parent marker (header or update parent) has been processed before any entry batches.
Sourcepub fn on_marker(
&mut self,
bank: Arc<Bank>,
parent_bank: Arc<Bank>,
shred_version: u16,
marker: VersionedBlockMarker,
allow_initial_update_parent: bool,
finalization_cert_sender: Option<&Sender<ConsensusMessage>>,
migration_status: &MigrationStatus,
) -> Result<(), BlockComponentProcessorError>
pub fn on_marker( &mut self, bank: Arc<Bank>, parent_bank: Arc<Bank>, shred_version: u16, marker: VersionedBlockMarker, allow_initial_update_parent: bool, finalization_cert_sender: Option<&Sender<ConsensusMessage>>, migration_status: &MigrationStatus, ) -> Result<(), BlockComponentProcessorError>
Process a block marker:
- Pre migration, no block markers are allowed
- During the migration only header and genesis certificate are allowed:
- This is in case our node was slow in observing the completion of the migration
- By seeing the first alpenglow block, we can advance the migration phase
- Once the migration is complete all markers are allowed
Sourcepub fn on_genesis_cert_block_marker(
&self,
bank: Arc<Bank>,
shred_version: u16,
genesis_block_marker: GenesisCertBlockMarker,
migration_status: &MigrationStatus,
) -> Result<(), BlockComponentProcessorError>
pub fn on_genesis_cert_block_marker( &self, bank: Arc<Bank>, shred_version: u16, genesis_block_marker: GenesisCertBlockMarker, migration_status: &MigrationStatus, ) -> Result<(), BlockComponentProcessorError>
Processes the genesis block marker with full verification
Sourcepub fn on_genesis_cert_block_marker_leader(
&self,
bank: Arc<Bank>,
genesis_block_marker: GenesisCertBlockMarker,
migration_status: &MigrationStatus,
) -> Result<(), BlockComponentProcessorError>
pub fn on_genesis_cert_block_marker_leader( &self, bank: Arc<Bank>, genesis_block_marker: GenesisCertBlockMarker, migration_status: &MigrationStatus, ) -> Result<(), BlockComponentProcessorError>
Processes a locally produced genesis certificate marker without re-verifying the certificate signature.
Sourcepub fn nanosecond_time_bounds(
parent_time_nanos: i64,
elapsed_slot_duration_nanos: u128,
) -> (i64, i64)
pub fn nanosecond_time_bounds( parent_time_nanos: i64, elapsed_slot_duration_nanos: u128, ) -> (i64, i64)
Given a parent time and elapsed slot duration, calculates inclusive block producer timestamp bounds.
parent_time_nanos describes the parent bank’s nanosecond clock.
elapsed_slot_duration_nanos is the summed duration for all skipped
and working slots after the parent. The returned (lower_bound, upper_bound) accepts timestamps where
lower_bound <= working_bank_time <= upper_bound.
Refer to https://github.com/solana-foundation/solana-improvement-documents/pull/363 for details on the bounds calculation.