Trait solana_runtime::bloom::BloomHashIndex [−][src]
pub trait BloomHashIndex {
fn hash_at_index(&self, hash_index: u64) -> u64;
}Expand description
Generate a stable hash of self for each hash_index
Best effort can be made for uniqueness of each hash.
Required methods
fn hash_at_index(&self, hash_index: u64) -> u64[src]
Implementors
impl<T: AsRef<[u8]>> BloomHashIndex for T[src]
impl<T: AsRef<[u8]>> BloomHashIndex for T[src]