👎Deprecated since 3.1.0:
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Structs
- Prioritization
FeeCache Deprecated - Stores up to MAX_NUM_RECENT_BLOCKS recent block’s prioritization fee,
A separate internal thread
service_threadhandles additional tasks when a bank is frozen, and collecting stats and reporting metrics.