ExtraFieldsToSerialize

Struct ExtraFieldsToSerialize 

pub struct ExtraFieldsToSerialize {
    pub lamports_per_signature: u64,
    pub unused_incremental_snapshot_persistence: Option<UnusedIncrementalSnapshotPersistence>,
    pub unused_epoch_accounts_hash: Option<Hash>,
    pub versioned_epoch_stakes: HashMap<u64, VersionedEpochStakes>,
    pub accounts_lt_hash: Option<SerdeAccountsLtHash>,
    pub block_id: Option<Hash>,
}
Extra fields that are serialized at the end of snapshots.

Note that this struct’s fields should stay synced with the fields in ExtraFieldsToDeserialize with the exception that new “extra fields” should be added to the deserialize struct a minor release before they are added to this one.

Fields

lamports_per_signature: u64unused_incremental_snapshot_persistence: Option<UnusedIncrementalSnapshotPersistence>unused_epoch_accounts_hash: Option<Hash>versioned_epoch_stakes: HashMap<u64, VersionedEpochStakes>accounts_lt_hash: Option<SerdeAccountsLtHash>block_id: Option<Hash>