Module snapshot_package

Module snapshot_package 

Structs

BankSnapshotPackage
A package created from a snapshot request, containing information required to serialize the bank snapshot
SnapshotPackage
This struct packages up fields to send to SnapshotPackagerService

Functions

are_snapshot_archive_kinds_the_same_kind
Check if two snapshot archives are the same kind
are_snapshot_kinds_the_same_kind
Check if two snapshot kinds are the same kind
are_snapshot_packages_the_same_kind
Check if two snapshots packages are the same kind
cmp_snapshot_archive_kinds_by_priority
Compare snapshot archive kinds by priority
cmp_snapshot_kinds_by_priority
Compare snapshot kinds by priority
cmp_snapshot_packages_by_priority
Compare snapshot packages by priority; first by kind, then by slot