pub struct SnapshotPackage {
pub snapshot_kind: SnapshotKind,
pub slot: Slot,
pub block_height: Slot,
pub hash: SnapshotHash,
pub snapshot_storages: Vec<Arc<AccountStorageEntry>>,
pub status_cache_slot_deltas: Vec<BankSlotDelta>,
pub bank_fields_to_serialize: BankFieldsToSerialize,
pub bank_hash_stats: BankHashStats,
pub write_version: u64,
pub enqueued: Instant,
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
This struct packages up fields to send to SnapshotPackagerService
Fields
snapshot_kind: SnapshotKindThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
slot: SlotThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
block_height: SlotThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
hash: SnapshotHashThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
snapshot_storages: Vec<Arc<AccountStorageEntry>>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
status_cache_slot_deltas: Vec<BankSlotDelta>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
bank_fields_to_serialize: BankFieldsToSerializeThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
bank_hash_stats: BankHashStatsThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
write_version: u64This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
enqueued: InstantThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
The instant this snapshot package was sent to the queue. Used to track how long snapshot packages wait before handling.
Implementations
Sourceimpl SnapshotPackage
impl SnapshotPackage
pub fn new( snapshot_kind: SnapshotKind, bank: &Bank, snapshot_storages: Vec<Arc<AccountStorageEntry>>, status_cache_slot_deltas: Vec<BankSlotDelta>, ) -> Self
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.