pub enum VerifyBank {
Deterministic,
NonDeterministic,
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
allow tests to specify what happened to the serialized format
Variants
Deterministic
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
the bank’s serialized format is expected to be identical to what we are comparing against
NonDeterministic
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
the serialized bank was ‘reserialized’ into a non-deterministic format so, deserialize both files and compare deserialized results