Struct solana_runtime::snapshot_utils::SlotSnapshotPaths [−][src]
pub struct SlotSnapshotPaths {
pub slot: Slot,
pub snapshot_file_path: PathBuf,
}Fields
slot: Slotsnapshot_file_path: PathBufTrait Implementations
impl Debug for SlotSnapshotPaths[src]
impl Debug for SlotSnapshotPaths[src]impl Ord for SlotSnapshotPaths[src]
impl Ord for SlotSnapshotPaths[src]impl PartialEq<SlotSnapshotPaths> for SlotSnapshotPaths[src]
impl PartialEq<SlotSnapshotPaths> for SlotSnapshotPaths[src]fn eq(&self, other: &SlotSnapshotPaths) -> bool[src]
fn eq(&self, other: &SlotSnapshotPaths) -> bool[src]This method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(&self, other: &SlotSnapshotPaths) -> bool[src]
fn ne(&self, other: &SlotSnapshotPaths) -> bool[src]This method tests for !=.
impl PartialOrd<SlotSnapshotPaths> for SlotSnapshotPaths[src]
impl PartialOrd<SlotSnapshotPaths> for SlotSnapshotPaths[src]fn partial_cmp(&self, other: &Self) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Self) -> Option<Ordering>[src]This method returns an ordering between self and other values if one exists. Read more
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for SlotSnapshotPaths[src]
impl StructuralEq for SlotSnapshotPaths[src]
impl StructuralPartialEq for SlotSnapshotPaths[src]