Module stake_utils

Module stake_utils 

Functions

create_stake_account
Utility function for creating a stake account from basic parameters. Only used in tests and CLIs.
get_minimum_delegation
The minimum stake amount that can be delegated, in lamports. When this feature is added, it will be accompanied by an upgrade to the BPF Stake Program. NOTE: This is also used to calculate the minimum balance of a delegated stake account, which is the rent exempt reserve plus the minimum stake delegation.