pub struct StatusCache<T: Serialize + Clone> { /* private fields */ }Implementations
Sourceimpl<T: Serialize + Clone> StatusCache<T>
impl<T: Serialize + Clone> StatusCache<T>
Sourcepub fn clear_slot_entries(&mut self, slot: Slot)
pub fn clear_slot_entries(&mut self, slot: Slot)
Clear all entries for a slot.
This is used when a slot is purged from the cache, see ReplayStage::purge_unconfirmed_duplicate_slot().
When this is called, it’s guaranteed that there are no threads inserting new entries for this slot. root_slot_deltas() also never accesses slots that are being cleared because roots are never purged.
Sourcepub fn get_status<K: AsRef<[u8]>>(
&self,
key: K,
transaction_blockhash: &Hash,
ancestors: &Ancestors,
) -> Option<(Slot, T)>
pub fn get_status<K: AsRef<[u8]>>( &self, key: K, transaction_blockhash: &Hash, ancestors: &Ancestors, ) -> Option<(Slot, T)>
Check if the key is in any of the forks in the ancestors set and with a certain blockhash.
Sourcepub fn get_status_any_blockhash<K: AsRef<[u8]>>(
&self,
key: K,
ancestors: &Ancestors,
) -> Option<(Slot, T)>
pub fn get_status_any_blockhash<K: AsRef<[u8]>>( &self, key: K, ancestors: &Ancestors, ) -> Option<(Slot, T)>
Search for a key with any blockhash.
Prefer get_status for performance reasons, it doesn’t need to search all blockhashes.
Sourcepub fn add_root(&mut self, fork: Slot)
pub fn add_root(&mut self, fork: Slot)
Add a known root fork.
Roots are always valid ancestors. After max_root_entries, roots are removed, and any old
keys are cleared.
pub fn add_roots<I: IntoIterator<Item = Slot>>(&mut self, forks: I)
pub fn roots(&self) -> &HashSet<Slot>
pub fn max_root_entries(&self) -> usize
pub fn set_max_root_entries(&mut self, max_root_entries: NonZeroUsize)
Sourcepub fn insert<K: AsRef<[u8]>>(
&mut self,
transaction_blockhash: &Hash,
key: K,
slot: Slot,
res: T,
)
pub fn insert<K: AsRef<[u8]>>( &mut self, transaction_blockhash: &Hash, key: K, slot: Slot, res: T, )
Insert a new key using the given blockhash at the given slot.
pub fn purge_roots(&mut self)
pub fn clear(&mut self)
Sourcepub fn root_slot_deltas(&self) -> Vec<SlotDelta<T>> ⓘ
pub fn root_slot_deltas(&self) -> Vec<SlotDelta<T>> ⓘ
Get the statuses for all the root slots.
This is never called concurrently with add_root(), and for a slot to be a root there must be no new entries for that slot, so there are no races.
See ReplayStage::handle_new_root() => BankForks::set_root() => BankForks::do_set_root_return_metrics() => root_slot_deltas()