Module test_utils

Module test_utils 

Functions

new_rand_vote_account
Creates a vote account set_bls_pubkey: controls whether the bls pubkey is None or Some
new_rand_vote_accounts
new_staked_vote_accounts
Creates num_nodes random vote accounts with the specified stake. The first num_nodes_with_bls_pubkeys have the bls_pubkeys set while the rest are unset. If stake_per_node is specified, then each node will have that stake, otherwise a random amount between min_stake_for_staked_account and max_stake_for_staked_account is chosen.
staked_nodes