ValidatedBlockFinalizationCert

Struct ValidatedBlockFinalizationCert 

pub struct ValidatedBlockFinalizationCert { /* private fields */ }
A validated proof that a block has been finalized.

This type can only be constructed through validation methods, providing compile-time guarantees that the contained certificates are valid.

Implementations

Source

impl ValidatedBlockFinalizationCert

Creates a validated block finalization certificate from a footer’s final certificate.

This method performs both BLS signature conversion and stake threshold verification against the provided bank’s epoch stakes.

Errors

Returns an error if:

  • BLS signature conversion fails
  • Certificate signature verification fails
  • The certificates don’t meet the required stake thresholds
pub fn from_validated_slow( finalize_cert: Certificate, notarize_cert: Certificate, bank: &Bank, ) -> Self

Creates a validated block finalization certificate from already-validated certificates.

This is intended for use by the consensus pool, where certificates have already been validated by the bls sigverifier

Safety

The caller must ensure that the provided certificates have been properly validated. Using unvalidated certificates will compromise the type’s safety guarantees.

pub fn from_validated_fast(cert: Certificate, bank: &Bank) -> Self

Creates a validated fast finalization certificate from an already-validated certificate.

This is intended for use by the consensus pool, where certificates have already been validated by the bls sigverifier

Safety

The caller must ensure that the provided certificate has been properly validated. Using an unvalidated certificate will compromise the type’s safety guarantees.

pub fn slot(&self) -> FinalizedSlot

Returns the slot that is finalized.

pub fn block(&self) -> Block

Returns the block that is finalized (slot, block_id).

pub fn is_fast(&self) -> bool

Returns true if this is a fast finalization.

pub fn clone_certificates(&self) -> Vec<Certificate>

Returns cloned copies of the certificates that prove this finalization.

For slow finalization this returns the finalize certificate followed by the notarize certificate. For fast finalization this returns the single fast-finalize certificate.

pub fn vote_rewards_input(&self) -> (&HashSet<Pubkey>, Slot)

Returns the data needed to calculating and paying vote rewards.

pub fn to_block_final_cert(&self) -> BlockFinalizationCert

Converts this validated certificate into a BlockFinalizationCert for inclusion in a block footer.