pub enum ReplayVoteMessage {
VerifiedExecuted(ParsedVote),
Executed {
replay_bank_id: BankId,
replay_slot: Slot,
message_hash: Hash,
parsed_vote: ParsedVote,
},
Verified {
replay_bank_id: BankId,
replay_slot: Slot,
message_hashes: Vec<Hash>,
},
InvalidBank {
replay_bank_id: BankId,
replay_slot: Slot,
},
BankComplete {
replay_bank_id: BankId,
replay_slot: Slot,
},
}Expand description
Message sent by banking and replay to the solCiProcVotes thread to update its state machine.
Banking sends VerifiedExecuted(vote) as it builds a block, and solCiProcVotes processes those votes immediately.
Replay runs sigverify and execution in parallel, and sends Verified and Executed respectively as those stages complete. solCiProcVotes waits until it has received both messages for the same vote transaction before processing it.
Variants
VerifiedExecuted(ParsedVote)
The vote was sigverified and executed
Executed
The vote was executed, but sigverify might not have finished yet
Verified
The votes were sigverified.
InvalidBank
The bank is invalid no more votes should be processed.
This is informative and used to release memory early. If not sent (like in some replay error paths), memory will be released as slots are rooted.
BankComplete
The bank is complete.
Like InvalidBank this is informative and used to release memory early.