pub struct BankWithScheduler { /* private fields */ }Expand description
Very thin wrapper around Arc
It brings type-safety against accidental mixing of bank and scheduler with different slots,
which is a pretty dangerous condition. Also, it guarantees to call wait_for_termination() via
::drop() by DropBankService, which receives Vec
Semantically, a scheduler is tightly coupled with a particular bank. But scheduler wasn’t put
into Bank fields to avoid circular-references (a scheduler needs to refer to its accompanied
Arcbank variable names should be
used for BankWithScheduler across codebase.
BankWithScheduler even implements Deref for convenience. And Clone is omitted to implement to
avoid ambiguity as to which to clone: BankWithScheduler or Arc
Implementations
Sourceimpl BankWithScheduler
impl BankWithScheduler
Sourcepub fn new(bank: Arc<Bank>, scheduler: Option<InstalledSchedulerBox>) -> Self
pub fn new(bank: Arc<Bank>, scheduler: Option<InstalledSchedulerBox>) -> Self
Creates a new BankWithScheduler from bank and its associated scheduler.
Panics
Panics if scheduler’s scheduling context is unmatched to given bank or for scheduler
preallocation.
pub fn new_without_scheduler(bank: Arc<Bank>) -> Self
pub fn clone_with_scheduler(&self) -> BankWithScheduler
pub fn clone_without_scheduler(&self) -> Arc<Bank> ⓘ
pub fn register_tick(&self, hash: &Hash)
pub fn fill_bank_with_ticks_for_tests(&self)
pub fn has_installed_scheduler(&self) -> bool
Sourcepub fn schedule_transaction_executions(
&self,
transaction_with_task_ids: impl ExactSizeIterator<Item = (RuntimeTransaction<SanitizedTransaction>, OrderedTaskId)>,
) -> Result<()>
pub fn schedule_transaction_executions( &self, transaction_with_task_ids: impl ExactSizeIterator<Item = (RuntimeTransaction<SanitizedTransaction>, OrderedTaskId)>, ) -> Result<()>
Schedule the transaction as long as the scheduler hasn’t been aborted.
If the scheduler has been aborted, this doesn’t schedule the transaction, instead just return the error of prior scheduled transaction.
Calling this will panic if the installed scheduler is Unavailable (the bank is wait_for_termination()-ed or the unified scheduler is disabled in the first place).
pub fn create_timeout_listener(&self) -> TimeoutListener
pub fn drop_scheduler(&mut self)
pub fn wait_for_completed_scheduler(&self) -> Option<ResultWithTimings>
pub const fn no_scheduler_available() -> InstalledSchedulerRwLock