pub struct ExtraFieldsToSerialize {
pub lamports_per_signature: u64,
pub unused_incremental_snapshot_persistence: Option<UnusedIncrementalSnapshotPersistence>,
pub unused_epoch_accounts_hash: Option<Hash>,
pub versioned_epoch_stakes: HashMap<u64, VersionedEpochStakes>,
pub accounts_lt_hash: Option<SerdeAccountsLtHash>,
pub block_id: Option<Hash>,
}Expand description
Extra fields that are serialized at the end of snapshots.
Note that this struct’s fields should stay synced with the fields in ExtraFieldsToDeserialize with the exception that new “extra fields” should be added to the deserialize struct a minor release before they are added to this one.
Fields
lamports_per_signature: u64unused_incremental_snapshot_persistence: Option<UnusedIncrementalSnapshotPersistence>unused_epoch_accounts_hash: Option<Hash>versioned_epoch_stakes: HashMap<u64, VersionedEpochStakes>accounts_lt_hash: Option<SerdeAccountsLtHash>block_id: Option<Hash>Trait Implementations
Sourceimpl AbiExample for ExtraFieldsToSerialize
impl AbiExample for ExtraFieldsToSerialize
Sourceimpl Debug for ExtraFieldsToSerialize
impl Debug for ExtraFieldsToSerialize
Sourceimpl Default for ExtraFieldsToSerialize
impl Default for ExtraFieldsToSerialize
Sourcefn default() -> ExtraFieldsToSerialize
fn default() -> ExtraFieldsToSerialize
Returns the “default value” for a type. Read more
Sourceimpl Distribution<ExtraFieldsToSerialize> for StandardUniform
impl Distribution<ExtraFieldsToSerialize> for StandardUniform
Sourcefn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> ExtraFieldsToSerialize
fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> ExtraFieldsToSerialize
Generate a random value of
T, using rng as the source of randomness.Sourcefn sample_iter<R>(self, rng: R) -> Iter<Self, R, T>
fn sample_iter<R>(self, rng: R) -> Iter<Self, R, T>
Create an iterator that generates random values of
T, using rng as
the source of randomness. Read moreSourceimpl PartialEq for ExtraFieldsToSerialize
impl PartialEq for ExtraFieldsToSerialize
Sourcefn eq(&self, other: &ExtraFieldsToSerialize) -> bool
fn eq(&self, other: &ExtraFieldsToSerialize) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExtraFieldsToSerialize
impl Serialize for ExtraFieldsToSerialize
Sourceimpl StableAbi for ExtraFieldsToSerialize
impl StableAbi for ExtraFieldsToSerialize
impl StructuralPartialEq for ExtraFieldsToSerialize