Structs
- Bank
Snapshot Package - A package created from a snapshot request, containing information required to serialize the bank snapshot
- Snapshot
Package - This struct packages up fields to send to SnapshotPackagerService
Functions
- are_
snapshot_ archive_ kinds_ the_ same_ kind - Check if two snapshot archives are the same kind
- are_
snapshot_ kinds_ the_ same_ kind - Check if two snapshot kinds are the same kind
- are_
snapshot_ packages_ the_ same_ kind - Check if two snapshots packages are the same kind
- cmp_
snapshot_ archive_ kinds_ by_ priority - Compare snapshot archive kinds by priority
- cmp_
snapshot_ kinds_ by_ priority - Compare snapshot kinds by priority
- cmp_
snapshot_ packages_ by_ priority - Compare snapshot packages by priority; first by kind, then by slot